@@ -16,15 +16,19 @@ from .rewrite import ASTImportRewriter, build_rewrites
 _PROTO_SUFFIX_PATTERN = re.compile(r"^(.+)\.proto$")
 
 
-def _remove_proto_suffix(name: str) -> str:
+def _clean_proto_filename(name: str) -> str:
     """Remove the `.proto` suffix from `name`.
 
     Examples
     --------
-    >>> _remove_proto_suffix("a/b.proto")
+    >>> _clean_proto_filename("a/b.proto")
     'a/b'
+    >>> _clean_proto_filename("a/b-c.proto")
+    'a/b_c'
+    >>> _clean_proto_filename("a/b_c.proto")
+    'a/b_c'
     """
-    return _PROTO_SUFFIX_PATTERN.sub(r"\1", name)
+    return _PROTO_SUFFIX_PATTERN.sub(r"\1", name).replace("-", "_")
 
 
 def _should_ignore(fd_name: str, patterns: Sequence[str]) -> bool:
@@ -48,7 +52,7 @@ class FileDescriptorSetGenerator(abc.ABC):
 
     @abc.abstractmethod
     def generate_file_descriptor_set_bytes(self) -> bytes:
-        """Generate the bytes of a `FileDescriptorSet`"""
+        """Generate the bytes of a `FileDescriptorSet`."""
 
     def fix_imports(
         self,
@@ -67,7 +71,7 @@ class FileDescriptorSetGenerator(abc.ABC):
             if _should_ignore(fd.name, exclude_imports_glob):
                 continue
 
-            fd_name = _remove_proto_suffix(fd.name)
+            fd_name = _clean_proto_filename(fd.name)
             rewriter = ASTImportRewriter()
             # services live outside of the corresponding generated Python
             # module, but they import it so we register a rewrite for the
@@ -77,11 +81,11 @@ class FileDescriptorSetGenerator(abc.ABC):
                 rewriter.register_rewrite(repl)
 
             # register proto import rewrites
-            for dep in map(_remove_proto_suffix, fd.dependency):
+            for dep in map(_clean_proto_filename, fd.dependency):
                 if _should_ignore(dep, exclude_imports_glob):
                     continue
 
-                dep_name = _remove_proto_suffix(dep)
+                dep_name = _clean_proto_filename(dep)
                 for repl in build_rewrites(fd_name, dep_name):
                     rewriter.register_rewrite(repl)
 
@@ -98,19 +102,30 @@ class FileDescriptorSetGenerator(abc.ABC):
         if create_package:
             # recursively create packages
             for dir_entry in itertools.chain([python_out], python_out.rglob("*")):
-                if dir_entry.is_dir():
+                if dir_entry.is_dir() and "__pycache__" not in dir_entry.parts:
                     dir_entry.joinpath("__init__.py").touch(exist_ok=True)
                     if has_pyi:
                         _create_pyi_init(dir_entry)
 
 
 def _create_pyi_init(root: Path) -> None:
-    with root.joinpath("__init__.pyi").open(mode="a") as f:
-        f.writelines(
-            f"from . import {path.stem}\n"
-            for path in root.glob("*")
-            if path.stem != "__init__" and (path.suffix == ".pyi" or path.is_dir())
-        )
+    # use a dictionary to preserve order while deduplicating
+    lines_to_write = {
+        f"from . import {path.stem}\n": None
+        for path in sorted(root.glob("*"))
+        if path.stem not in ("__init__", "__pycache__")
+        if path.suffix == ".pyi" or path.is_dir()
+    }
+    path = root.joinpath("__init__.pyi")
+
+    if not path.exists():
+        path.write_text("".join(lines_to_write))
+    else:
+        with path.open(mode="r") as f:
+            for line in f:
+                lines_to_write.pop(line, None)
+        with path.open(mode="a") as f:
+            f.writelines(lines_to_write)
 
 
 class Protoc(FileDescriptorSetGenerator):
